@@ -2,12 +2,10 @@ from biopandas.pdb import PandasPdb
 import pandas
 import math
 import numpy
-import mdtraj
 
 def ReadPDBintoDataFrame(PDBfileNameString):
     t= PandasPdb().read_pdb(PDBfileNameString).df["ATOM"]
     df = pandas.DataFrame(t)
-    df.traj = mdtraj.load(PDBfileNameString)
     return df 
 def RetreivePDBatomPosition(dataFramePDB, segmentIDstring, residueNumber, atomNameString):
     df1 = dataFramePDB.loc[dataFramePDB["segment_id"]== segmentIDstring]
@@ -82,22 +80,6 @@ def ConvertToThreeLetter(seq, custom_map=None, undef_code="Xaa"):
     # Note this will map '-' to 'Xaa' which may be undesirable!
     return "".join(threecode.get(aa, undef_code) for aa in seq)
 
-def GetPhiAngles(dataFramePDB):
-    t= dataFramePDB.traj
-    tphi_indices, tphi_atoms = mdtraj.compute_phi(t)
-    tphi_atoms = numpy.atleast_2d(tphi_atoms).T
-    tphi_indices = numpy.array(tphi_indices)
-    num_rows, num_columns = tphi_indices.shape
-    nf = numpy.append(tphi_indices, tphi_atoms, 1)
-    return nf
-def GetPsiAngles(dataFramePDB):
-    t= dataFramePDB.traj
-    tpsi_indices, tpsi_atoms = mdtraj.compute_psi(t)
-    tpsi_atoms = numpy.atleast_2d(tpsi_atoms).T
-    tpsi_indices = numpy.array(tpsi_indices)
-    num_rows, num_columns = tpsi_indices.shape
-    nf = numpy.append(tpsi_indices, tpsi_atoms, 1)
-    return nf
 def GetHydrogenBondDistances(dataFramePDB, resstart, resstop, segstart, segstop):
     residues2check = numpy.arange(resstart, resstop+1, 2)
     HBondDistances= numpy.zeros((segstop-segstart, len(residues2check)))
